@@ -9,7 +9,7 @@ from ajaxuploader.backends.base import AbstractUploadBackend
 class S3UploadBackend(AbstractUploadBackend):
     NUM_PARALLEL_PROCESSES = 4
 
-    def upload_chunk(self, chunk):
+    def upload_chunk(self, chunk, *args, **kwargs):
         self._counter += 1
         buffer = StringIO()
         buffer.write(chunk)
@@ -18,7 +18,7 @@ class S3UploadBackend(AbstractUploadBackend):
         buffer.close()
         
 
-    def setup(self, filename):
+    def setup(self, filename, *args, **kwargs):
         self._bucket = boto.connect_s3(settings.AWS_ACCESS_KEY_ID,
                                        settings.AWS_SECRET_ACCESS_KEY)\
                             .lookup(settings.AWS_BUCKET_NAME)
@@ -26,7 +26,7 @@ class S3UploadBackend(AbstractUploadBackend):
         self._pool = Pool(processes=self.NUM_PARALLEL_PROCESSES)
         self._counter = 0
 
-    def upload_complete(self, request, filename):
+    def upload_complete(self, request, filename, *args, **kwargs):
         # Tie up loose ends, and finish the upload
         self._pool.close()
         self._pool.join()
